package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmReportAppointmentDay;
import com.ruoyi.powerdistribution.service.IPdmReportAppointmentDayService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 履职日统计Controller
 *
 * @author ruoyi
 * @date 2024-11-28
 */
@RestController
@RequestMapping("/power/appointment")
public class PdmReportAppointmentDayController extends BaseController
{
    @Autowired
    private IPdmReportAppointmentDayService pdmReportAppointmentDayService;

    /**
     * 查询履职日统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:day:list')")
    @GetMapping("/list")
    public TableDataInfo list(PdmReportAppointmentDay pdmReportAppointmentDay)
    {
        startPage();
        List<PdmReportAppointmentDay> list = pdmReportAppointmentDayService.selectPdmReportAppointmentDayList(pdmReportAppointmentDay);
        return getDataTable(list);
    }

    /**
     * 导出履职日统计列表
     */
    @PreAuthorize("@ss.hasPermi('system:day:export')")
    @Log(title = "履职日统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmReportAppointmentDay pdmReportAppointmentDay)
    {
        List<PdmReportAppointmentDay> list = pdmReportAppointmentDayService.selectPdmReportAppointmentDayList(pdmReportAppointmentDay);
        ExcelUtil<PdmReportAppointmentDay> util = new ExcelUtil<PdmReportAppointmentDay>(PdmReportAppointmentDay.class);
        util.exportExcel(response, list, "履职日统计数据");
    }

    /**
     * 获取履职日统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:day:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmReportAppointmentDayService.selectPdmReportAppointmentDayById(id));
    }

    /**
     * 新增履职日统计
     */
    @PreAuthorize("@ss.hasPermi('system:day:add')")
    @Log(title = "履职日统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmReportAppointmentDay pdmReportAppointmentDay)
    {
        return toAjax(pdmReportAppointmentDayService.insertPdmReportAppointmentDay(pdmReportAppointmentDay));
    }

    /**
     * 修改履职日统计
     */
    @PreAuthorize("@ss.hasPermi('system:day:edit')")
    @Log(title = "履职日统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmReportAppointmentDay pdmReportAppointmentDay)
    {
        return toAjax(pdmReportAppointmentDayService.updatePdmReportAppointmentDay(pdmReportAppointmentDay));
    }

    /**
     * 删除履职日统计
     */
    @PreAuthorize("@ss.hasPermi('system:day:remove')")
    @Log(title = "履职日统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmReportAppointmentDayService.deletePdmReportAppointmentDayByIds(ids));
    }
}
